#!/usr/bin/env python
# -*- coding: utf-8 -*-

# # 2A.eco - Mise en pratique des séances 1 et 2 - Utilisation de pandas et visualisation - correction
# 
# Correction d'un exercice sur la manipulation des données.

# In[1]:


from jyquickhelper import add_notebook_menu
add_notebook_menu()


# In[2]:


from pyensae.datasource import download_data
files = download_data("td2a_eco_exercices_de_manipulation_de_donnees.zip",
                      url="https://github.com/sdpython/ensae_teaching_cs/raw/master/_doc/notebooks/td2a_eco/data/")
files


# ## Exercice 1 - manipulation des bases
# 
# Durée : 10 minutes
# 
# 1. Importer la base de données relatives aux joueurs de la Coupe du Monde 2014
# 2. Déterminer le nombre de joueurs dans chaque équipe et créer un dictionnaire { équipe : Nombre de joueurs}
# 3. Déterminer quels sont les 3 joueurs qui ont couvert le plus de distance. Y a t il un biais de sélection ?
# 4. Parmis les joueurs qui sont dans le premier décile des joueurs plus rapides, qui a passé le plus clair de son temps à courrir sans la balle ?

# # Import du fichier

# In[3]:


import pandas as pd
data_players = pd.read_excel("Players_WC2014.xlsx", engine='openpyxl')


# In[4]:


data_players.head()


# ## Nombre de joueurs par équipe

# In[5]:


data_players.groupby(['Team']).size().to_dict()


# ## Les joueurs ayant couvert le plus de distance

# In[6]:


## quels joueurs ont couvert le plus de distance ? 
data_players['Distance Covered'] = data_players['Distance Covered'].str.replace('km','')


# In[7]:


data_players['Distance Covered'] = pd.to_numeric(data_players['Distance Covered'])
data_players.sort_values(['Distance Covered'], ascending = 0).head(n=3)


# On voit un clair effet de sélection sur cette variable : ce sont les joueurs dont les équipes ont été le plus loin dans la compétition qui couvert le plus de distance.

# ## Qui a été le plus efficace ?
# 
# On a besoin de rendre la variable Top Speed numérique, et de créer une nouvelle variable avec le poucentage de possession de balle

# In[8]:


## Qui a été le plus rapide ?

data_players['Top Speed'] = data_players['Top Speed'].str.replace('km/h','')
data_players['Top Speed'] = pd.to_numeric(data_players['Top Speed'])
data_players.sort_values(['Top Speed'], ascending = 0).head(n=3)


# In[9]:


## Parmis ceux qui sont dans le décile des plus rapides, qui a passé le plus clair de son temps à courrir sans la balle ?
data_players['Distance Covered In Possession'] = data_players['Distance Covered In Possession'].str.replace('km','')
data_players['Distance Covered In Possession'] = pd.to_numeric(data_players['Distance Covered In Possession'])
data_players['Share of Possession'] = data_players['Distance Covered In Possession']/data_players['Distance Covered']


# In[10]:


data_players[data_players['Top Speed'] > data_players['Top Speed'].
             quantile(.90)].sort_values(['Share of Possession'], ascending = 0).head()